@@ -58,8 +58,8 @@ class matrix(np.ndarray):
                 for j in range(m):
                     for k in range(p):
                         for l in range(q):
-                            I = k + p * (i-1)
-                            J = l + q * (j-1)
+                            I = k + p * (i)
+                            J = l + q * (j)
                             ret[I, J] = self[i,j] * other[k, l]
             return matrix(ret)
         return super.__pow__(other)
@@ -254,6 +254,12 @@ class diffmatrix:
         if isinstance(other, np.ndarray) and not isinstance(other, matrix):
             return self.__mul__(matrix(other))
         if isinstance(other, matrix):
+            if self.left_size == (1, 1) and other.shape[0] != 1:
+                ret = create_matrix(*other.shape, *self.right_size, style="zero")
+                for i in range(other.shape[0]):
+                    for j in range(other.shape[1]):
+                        ret[i, j, :, :] = ret[i, j, :, :] + other[i, j] * self.matrix[0, 0, :, :]
+                return diffmatrix(matrix(ret))
             assert other.dim() == 2
             assert other.shape[0] == self.left_size[1]
             ret = create_matrix(self.left_size[0], other.shape[1], *self.right_size, style="zero")
